pub struct VerificationKey {
pub g1s: Vec<G1Point>,
pub g2s: Vec<G2Point>,
pub g2_gen: G2Point,
pub coset_size: usize,
pub num_coefficients_in_polynomial: usize,
}Expand description
Verification Key is used to verify opening proofs made about a committed polynomial.
Fields
g1s: Vec<G1Point>The powers of tau G1 used in the setup
ie group elements of the form { \tau^i G }
g2s: Vec<G2Point>The powers of tau G2 used in the setup
ie group elements of the form { \tau^i G }
g2_gen: G2PointThe degree-0 term in the powers of tau G2 elements.
coset_size: usizeThis is the number of points that will be a opened at any one time. Another way to think of this, is that its the number of points a proof will attest to.
In most cases, this is the number of G1 elements, however, we have this explicit parameter to avoid foot guns.
num_coefficients_in_polynomial: usizeThe number of coefficients in the polynomial that we want to verify claims about.
Note: We could also use the max degree bound here. (This is a matter of preference)
Implementations
Sourceimpl VerificationKey
impl VerificationKey
pub fn new( g1s: Vec<G1Point>, g2s: Vec<G2Point>, coset_size: usize, num_coefficients_in_polynomial: usize, ) -> Self
Sourcepub fn commit_g2(&self, polynomial: &[Scalar]) -> G2Projective
pub fn commit_g2(&self, polynomial: &[Scalar]) -> G2Projective
Commit to a polynomial in monomial form using the G2 group elements
Sourcepub fn commit_g1(&self, polynomial: &[Scalar]) -> G1Projective
pub fn commit_g1(&self, polynomial: &[Scalar]) -> G1Projective
Commit to a polynomial in monomial form using the G1 group elements